@@ -4,8 +4,8 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include "spectrumparser.h"
 #include "spectrum.h"
+#include "spectrumparser.h"
 #include <QDebug>
 #include <iostream>
 
@@ -16,7 +16,7 @@ int main(int argc, char *argv[])
         return 1;
     }
 
-    SpectrumParser *parser = new SpectrumParser();
+    auto parser = new SpectrumParser();
     QFile xmlFile(argv[1]);
 
     QXmlInputSource source(&xmlFile);
@@ -25,14 +25,14 @@ int main(int argc, char *argv[])
     reader.setContentHandler(parser);
     reader.parse(source);
 
-    QList<Spectrum *> v = parser->getSpectrums();
+    const QList<Spectrum *> v = parser->getSpectrums();
 
     qDebug() << "Found " << v.count() << " isotopes.";
 
-    foreach (Spectrum *s, v) {
+    for (Spectrum *s : v) {
         if (s) {
             qDebug() << "Element:  " << s->parentElementNumber();
-            foreach (Spectrum::peak * p , s->peaklist()) {
+            for (Spectrum::peak *p : s->peaklist()) {
                 qDebug() << "         Peak: " << p->wavelength;
             }
         }
