@@ -9,41 +9,40 @@
 #include <QDialog>
 #include <QListWidget>
 
-#include <element.h>
 #include "kalziumdataobject.h"
 #include "ui_exportdialog.h"
-
+#include <element.h>
 
 class ElementListEntry : public QListWidgetItem
 {
 public:
     explicit ElementListEntry(Element *element);
-    ~ElementListEntry();
+    ~ElementListEntry() override;
 
-    int       m_atomicNum;
-    QString   m_name;
-    Element  *m_element;
+    int m_atomicNum;
+    QString m_name;
+    Element *m_element = nullptr;
 };
 
 class PropertyListEntry : public QListWidgetItem
 {
 public:
-    PropertyListEntry(const QString & name, ChemicalDataObject::BlueObelisk type);
-    ~PropertyListEntry();
+    PropertyListEntry(const QString &name, ChemicalDataObject::BlueObelisk type);
+    ~PropertyListEntry() override;
 
     ChemicalDataObject::BlueObelisk m_type;
 };
 
 /**
-* @author: Johannes Simon
-*/
+ * @author: Johannes Simon
+ */
 class ExportDialog : public QDialog
 {
     Q_OBJECT
 
 public:
     explicit ExportDialog(QWidget *parent);
-    ~ExportDialog();
+    ~ExportDialog() override;
 
     void populateElementList();
     void exportToHtml();
@@ -52,7 +51,7 @@ public:
 
 private:
     Ui::exportDialogForm ui;
-    QTextStream *m_outputStream;
+    QTextStream *m_outputStream = nullptr;
 
 public Q_SLOTS:
     void slotOkClicked();
@@ -60,7 +59,6 @@ public Q_SLOTS:
      * Open help page
      */
     void slotHelpRequested();
-
 };
 
 #endif // EXPORTDIALOG_H
