@@ -7,8 +7,8 @@
 #include "kalziumgradienttype.h"
 
 #include "element.h"
-#include "prefs.h"
 #include "kalziumdataobject.h"
+#include "prefs.h"
 
 #include "kalzium_debug.h"
 #include <QVariant>
@@ -16,7 +16,7 @@
 #include <KLocalizedString>
 #include <KUnitConversion/Converter>
 
-#include <math.h>
+#include <cmath>
 
 KalziumGradientTypeFactory::KalziumGradientTypeFactory()
 {
@@ -32,13 +32,13 @@ KalziumGradientTypeFactory::KalziumGradientTypeFactory()
     m_gradients << KalziumIonizationGradientType::instance();
 }
 
-KalziumGradientTypeFactory* KalziumGradientTypeFactory::instance()
+KalziumGradientTypeFactory *KalziumGradientTypeFactory::instance()
 {
     static KalziumGradientTypeFactory kttf;
     return &kttf;
 }
 
-KalziumGradientType* KalziumGradientTypeFactory::build(int id) const
+KalziumGradientType *KalziumGradientTypeFactory::build(int id) const
 {
     if ((id < 0) || (id >= m_gradients.count()))
         return nullptr;
@@ -46,7 +46,7 @@ KalziumGradientType* KalziumGradientTypeFactory::build(int id) const
     return m_gradients.at(id);
 }
 
-KalziumGradientType* KalziumGradientTypeFactory::build(const QByteArray& id) const
+KalziumGradientType *KalziumGradientTypeFactory::build(const QByteArray &id) const
 {
     for (int i = 0; i < m_gradients.count(); ++i) {
         if (m_gradients.at(i)->name() == id) {
@@ -66,16 +66,11 @@ QStringList KalziumGradientTypeFactory::gradients() const
     return l;
 }
 
+KalziumGradientType::KalziumGradientType() = default;
 
-KalziumGradientType::KalziumGradientType()
-{
-}
+KalziumGradientType::~KalziumGradientType() = default;
 
-KalziumGradientType::~KalziumGradientType()
-{
-}
-
-KalziumGradientType* KalziumGradientType::instance()
+KalziumGradientType *KalziumGradientType::instance()
 {
     return nullptr;
 }
@@ -130,7 +125,8 @@ QColor KalziumGradientType::notAvailableColor() const
 
 QColor KalziumGradientType::calculateColor(const double coeff) const
 {
-    if ((coeff < 0.0) || (coeff > 1.0)) return notAvailableColor();
+    if ((coeff < 0.0) || (coeff > 1.0))
+        return notAvailableColor();
 
     QColor color2 = secondColor();
     QColor color1 = firstColor();
@@ -139,17 +135,17 @@ QColor KalziumGradientType::calculateColor(const double coeff) const
     int green = static_cast<int>((color2.green() - color1.green()) * coeff + color1.green());
     int blue = static_cast<int>((color2.blue() - color1.blue()) * coeff + color1.blue());
 
-    return QColor(red, green, blue);
+    return {red, green, blue};
 }
 
-KalziumCovalentRadiusGradientType* KalziumCovalentRadiusGradientType::instance()
+KalziumCovalentRadiusGradientType *KalziumCovalentRadiusGradientType::instance()
 {
     static KalziumCovalentRadiusGradientType kcrgt;
     return &kcrgt;
 }
 
 KalziumCovalentRadiusGradientType::KalziumCovalentRadiusGradientType()
-        : KalziumGradientType()
+    : KalziumGradientType()
 {
 }
 
@@ -165,9 +161,9 @@ QString KalziumCovalentRadiusGradientType::description() const
 
 double KalziumCovalentRadiusGradientType::value(int el) const
 {
-    QVariant v = KalziumDataObject::instance()->element(el)
-                 ->dataAsVariant(ChemicalDataObject::radiusCovalent, Prefs::lengthUnit());
-    if (v.type() != QVariant::Double) return -1;
+    QVariant v = KalziumDataObject::instance()->element(el)->dataAsVariant(ChemicalDataObject::radiusCovalent, Prefs::lengthUnit());
+    if (v.type() != QVariant::Double)
+        return -1;
     return v.toDouble();
 }
 
@@ -198,15 +194,14 @@ bool KalziumCovalentRadiusGradientType::logarithmicGradient() const
     return Prefs::logarithmicCovalentRadiusGradient();
 }
 
-
-KalziumVanDerWaalsRadiusGradientType* KalziumVanDerWaalsRadiusGradientType::instance()
+KalziumVanDerWaalsRadiusGradientType *KalziumVanDerWaalsRadiusGradientType::instance()
 {
     static KalziumVanDerWaalsRadiusGradientType kvdwrgt;
     return &kvdwrgt;
 }
 
 KalziumVanDerWaalsRadiusGradientType::KalziumVanDerWaalsRadiusGradientType()
-        : KalziumGradientType()
+    : KalziumGradientType()
 {
 }
 
@@ -222,9 +217,9 @@ QString KalziumVanDerWaalsRadiusGradientType::description() const
 
 double KalziumVanDerWaalsRadiusGradientType::value(int el) const
 {
-    QVariant v = KalziumDataObject::instance()->element(el)
-                 ->dataAsVariant(ChemicalDataObject::radiusVDW, Prefs::lengthUnit());
-    if (v.type() != QVariant::Double) return -1;
+    QVariant v = KalziumDataObject::instance()->element(el)->dataAsVariant(ChemicalDataObject::radiusVDW, Prefs::lengthUnit());
+    if (v.type() != QVariant::Double)
+        return -1;
     return v.toDouble();
 }
 
@@ -238,7 +233,6 @@ int KalziumVanDerWaalsRadiusGradientType::decimals() const
     return 1;
 }
 
-
 double KalziumVanDerWaalsRadiusGradientType::minValue() const
 {
     KUnitConversion::Value minValue(1.2, KUnitConversion::Angstrom);
@@ -256,15 +250,14 @@ bool KalziumVanDerWaalsRadiusGradientType::logarithmicGradient() const
     return Prefs::logarithmicVanDerWaalsRadiusGradient();
 }
 
-
-KalziumMassGradientType* KalziumMassGradientType::instance()
+KalziumMassGradientType *KalziumMassGradientType::instance()
 {
     static KalziumMassGradientType kargt;
     return &kargt;
 }
 
 KalziumMassGradientType::KalziumMassGradientType()
-        : KalziumGradientType()
+    : KalziumGradientType()
 {
 }
 
@@ -281,7 +274,8 @@ QString KalziumMassGradientType::description() const
 double KalziumMassGradientType::value(int el) const
 {
     QVariant v = KalziumDataObject::instance()->element(el)->dataAsVariant(ChemicalDataObject::mass);
-    if (v.type() != QVariant::Double) return -1;
+    if (v.type() != QVariant::Double)
+        return -1;
     return v.toDouble();
 }
 
@@ -310,14 +304,14 @@ bool KalziumMassGradientType::logarithmicGradient() const
     return Prefs::logarithmicMassGradient();
 }
 
-KalziumBoilingPointGradientType* KalziumBoilingPointGradientType::instance()
+KalziumBoilingPointGradientType *KalziumBoilingPointGradientType::instance()
 {
     static KalziumBoilingPointGradientType kbpgt;
     return &kbpgt;
 }
 
 KalziumBoilingPointGradientType::KalziumBoilingPointGradientType()
-        : KalziumGradientType()
+    : KalziumGradientType()
 {
 }
 
@@ -334,7 +328,8 @@ QString KalziumBoilingPointGradientType::description() const
 double KalziumBoilingPointGradientType::value(int el) const
 {
     QVariant v = KalziumDataObject::instance()->element(el)->dataAsVariant(ChemicalDataObject::boilingpoint, Prefs::temperatureUnit());
-    if (v.type() != QVariant::Double) return -1;
+    if (v.type() != QVariant::Double)
+        return -1;
     return v.toDouble();
 }
 
@@ -365,15 +360,14 @@ bool KalziumBoilingPointGradientType::logarithmicGradient() const
     return Prefs::logarithmicBoilingPointGradient();
 }
 
-
-KalziumMeltingPointGradientType* KalziumMeltingPointGradientType::instance()
+KalziumMeltingPointGradientType *KalziumMeltingPointGradientType::instance()
 {
     static KalziumMeltingPointGradientType kmpgt;
     return &kmpgt;
 }
 
 KalziumMeltingPointGradientType::KalziumMeltingPointGradientType()
-        : KalziumGradientType()
+    : KalziumGradientType()
 {
 }
 
@@ -390,7 +384,8 @@ QString KalziumMeltingPointGradientType::description() const
 double KalziumMeltingPointGradientType::value(int el) const
 {
     QVariant v = KalziumDataObject::instance()->element(el)->dataAsVariant(ChemicalDataObject::meltingpoint, Prefs::temperatureUnit());
-    if (v.type() != QVariant::Double) return -1;
+    if (v.type() != QVariant::Double)
+        return -1;
     return v.toDouble();
 }
 
@@ -421,14 +416,14 @@ bool KalziumMeltingPointGradientType::logarithmicGradient() const
     return Prefs::logarithmicMeltingPointGradient();
 }
 
-KalziumSOMGradientType* KalziumSOMGradientType::instance()
+KalziumSOMGradientType *KalziumSOMGradientType::instance()
 {
     static KalziumSOMGradientType kargt;
     return &kargt;
 }
 
 KalziumSOMGradientType::KalziumSOMGradientType()
-        : KalziumGradientType()
+    : KalziumGradientType()
 {
 }
 
@@ -450,7 +445,8 @@ double KalziumSOMGradientType::value(int el) const
 
 QString KalziumSOMGradientType::unit() const
 {
-    return KalziumDataObject::instance()->unitAsString(Prefs::temperatureUnit());;
+    return KalziumDataObject::instance()->unitAsString(Prefs::temperatureUnit());
+    ;
 }
 
 int KalziumSOMGradientType::decimals() const
@@ -473,18 +469,17 @@ double KalziumSOMGradientType::maxValue() const
 bool KalziumSOMGradientType::logarithmicGradient() const
 {
     return true;
-//     return Prefs::logarithmicSOMGradient();
+    //     return Prefs::logarithmicSOMGradient();
 }
 
-
-KalziumElectronegativityGradientType* KalziumElectronegativityGradientType::instance()
+KalziumElectronegativityGradientType *KalziumElectronegativityGradientType::instance()
 {
     static KalziumElectronegativityGradientType kegt;
     return &kegt;
 }
 
 KalziumElectronegativityGradientType::KalziumElectronegativityGradientType()
-        : KalziumGradientType()
+    : KalziumGradientType()
 {
 }
 
@@ -501,13 +496,14 @@ QString KalziumElectronegativityGradientType::description() const
 double KalziumElectronegativityGradientType::value(int el) const
 {
     QVariant v = KalziumDataObject::instance()->element(el)->dataAsVariant(ChemicalDataObject::electronegativityPauling);
-    if (v.type() != QVariant::Double) return -1;
+    if (v.type() != QVariant::Double)
+        return -1;
     return v.toDouble();
 }
 
 QString KalziumElectronegativityGradientType::unit() const
 {
-    return QString();
+    return {};
 }
 
 int KalziumElectronaffinityGradientType::decimals() const
@@ -530,16 +526,16 @@ bool KalziumElectronegativityGradientType::logarithmicGradient() const
     return Prefs::logarithmicElectronegativityGradient();
 }
 
-///DISCOVERYDATE///
+/// DISCOVERYDATE///
 
-KalziumDiscoverydateGradientType* KalziumDiscoverydateGradientType::instance()
+KalziumDiscoverydateGradientType *KalziumDiscoverydateGradientType::instance()
 {
     static KalziumDiscoverydateGradientType kegt;
     return &kegt;
 }
 
 KalziumDiscoverydateGradientType::KalziumDiscoverydateGradientType()
-        : KalziumGradientType()
+    : KalziumGradientType()
 {
 }
 
@@ -556,13 +552,14 @@ QString KalziumDiscoverydateGradientType::description() const
 double KalziumDiscoverydateGradientType::value(int el) const
 {
     QVariant v = KalziumDataObject::instance()->element(el)->dataAsVariant(ChemicalDataObject::date);
-    if (v.value<int>() == 0) return -1;
+    if (v.value<int>() == 0)
+        return -1;
     return v.toDouble();
 }
 
 QString KalziumDiscoverydateGradientType::unit() const
 {
-    return QString();
+    return {};
 }
 
 int KalziumDiscoverydateGradientType::decimals() const
@@ -570,7 +567,6 @@ int KalziumDiscoverydateGradientType::decimals() const
     return 0;
 }
 
-
 double KalziumDiscoverydateGradientType::minValue() const
 {
     return 1669.0;
@@ -586,17 +582,16 @@ bool KalziumDiscoverydateGradientType::logarithmicGradient() const
     return Prefs::logarithmicDiscoverydateGradient();
 }
 
+/// ELECTRONAFFINITY///
 
-///ELECTRONAFFINITY///
-
-KalziumElectronaffinityGradientType* KalziumElectronaffinityGradientType::instance()
+KalziumElectronaffinityGradientType *KalziumElectronaffinityGradientType::instance()
 {
     static KalziumElectronaffinityGradientType kegt;
     return &kegt;
 }
 
 KalziumElectronaffinityGradientType::KalziumElectronaffinityGradientType()
-        : KalziumGradientType()
+    : KalziumGradientType()
 {
 }
 
@@ -643,15 +638,16 @@ bool KalziumElectronaffinityGradientType::logarithmicGradient() const
     return Prefs::logarithmicElectronaffinityGradient();
 }
 
-///FIRST IONIZATINO///
+/// FIRST IONIZATINO///
 
-KalziumIonizationGradientType* KalziumIonizationGradientType::instance()
+KalziumIonizationGradientType *KalziumIonizationGradientType::instance()
 {
     static KalziumIonizationGradientType kegt;
     return &kegt;
 }
 
-KalziumIonizationGradientType::KalziumIonizationGradientType() : KalziumGradientType()
+KalziumIonizationGradientType::KalziumIonizationGradientType()
+    : KalziumGradientType()
 {
 }
 
