@@ -57,23 +57,27 @@ QPainterPath ElementItem::shape() const
 
 void ElementItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *, QWidget *)
 {
-    QPen pen;
-    pen.setColor(m_borderColor);
-    pen.setWidth(1);
-    painter->setPen(pen);
-
+    if (m_hovered) {
+        QPen pen;
+        pen.setColor(m_borderColor);
+        pen.setWidth(1);
+        painter->setPen(pen);
+    } else {
+        painter->setPen(Qt::NoPen);
+    }
     painter->setBrush(m_brush);
-
-    painter->drawRoundedRect(boundingRect(), m_width / 10, m_width / 10);
+    painter->drawRoundedRect(boundingRect(), 3, 3);
 
     if (isSelected()) {
         QColor selectedBackgroundColor = m_borderColor;
         selectedBackgroundColor.setAlpha(160);
         painter->setBrush(QBrush(QColor(selectedBackgroundColor)));
-        painter->drawRoundedRect(boundingRect(), m_width / 10, m_width / 10);
+        painter->drawRoundedRect(boundingRect(), 3, 3);
     }
 
+    QPen pen;
     pen.setColor(m_textColor);
+    pen.setWidth(1);
     painter->setPen(pen);
 
     QFont symbolFont;
@@ -126,6 +130,7 @@ void ElementItem::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
     setZValue(200);
     moveBy(-m_width / 4, -m_height / 4);
     setScale(1.5);
+    m_hovered = true;
     QGraphicsItem::hoverEnterEvent(event);
 }
 
@@ -135,6 +140,7 @@ void ElementItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
     moveBy(m_width / 4, m_height / 4);
     setZValue(100);
     setScale(1);
+    m_hovered = false;
     QGraphicsItem::hoverLeaveEvent(event);
 }
 
