@@ -27,18 +27,18 @@ public:
      */
     explicit SearchWidget(QWidget *parent = nullptr);
 
-    ~SearchWidget();
+    ~SearchWidget() override;
 
     void giveFocus();
 
 private Q_SLOTS:
-    void searchTextChanged(const QString& text);
+    void searchTextChanged(const QString &text);
     void slotReturnPressed();
     void doSearch();
 
 private:
-    KLineEdit *m_searchLine;
-    QTimer *m_timer;
+    KLineEdit *const m_searchLine;
+    QTimer *m_timer = nullptr;
 };
 
 #endif // KALZIUMSEARCHWIDGET_H
